==> iRRAM_2003_05.tar.gz: iRRAM_2003_05/src/REALmain.cc <==
/*

REALmain.cc -- implementation of main initialization routine
               for the iRRAM library
 
Copyright (C) 2003 Norbert Mueller
 
This file is part of the iRRAM Library.
 
The iRRAM Library is free software; you can redistribute it and/or modify
it under the terms of the GNU Library General Public License as published by
the Free Software Foundation; either version 2 of the License, or (at your
option) any later version.
 
The iRRAM Library is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
License for more details.
 
You should have received a copy of the GNU Library General Public License
along with the iRRAM Library; see the file COPYING.LIB.  If not, write to
the Free Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
MA 02111-1307, USA. 
*/
#include <math.h>
#include <stdlib.h>
#include <stdarg.h>
#include <string.h>



#include "iRRAM_core.h"

/* for debugging (time measuring):*/
#include <sys/time.h>
#include <sys/resource.h>
#include <unistd.h>
void resources(double& time, unsigned long& memory){
 struct rusage r;
 getrusage (RUSAGE_SELF,&r);
 time = r.ru_utime.tv_sec+0.000001*r.ru_utime.tv_usec;
// the following is not yet evaluated by linux.... 
 memory = r.ru_ixrss+r.ru_idrss+r.ru_isrss;
} 
/* end of debugging aids */

long printfausgaben=0;
long printfaufrufe=0;
char * eingabe;
char * position=eingabe;
long  eingabeplatz=150000;
long testanzahl=0;
long testaufrufe=0;
long * testwert;
long konvertanzahl=0;
long konvertaufrufe=0;
MP_type * konvert;

int iRRAM_debug=0;
int iRRAM_infinite=0;
long iRRAM_starting_prec=-50;
long iRRAM_stiff_prec_inc=-50;
long iRRAM_prec_inc0=0;
long iRRAM_prec_inc1=-50;
long iRRAM_prec_inc2=-50;

extern "C" void iRRAM_initialize(int argc,char **argv)
{

ACTUAL_STACK.inlimit=0;
ACTUAL_STACK.actual_prec=iRRAM_starting_prec;
ACTUAL_STACK.prec_inc=0;
ACTUAL_STACK.prec_factor=1.25;

int i;

for (i=0;i<argc;i+=1)
{
if (!strcmp(argv[i],"-d")) 
	{
	iRRAM_debug=1;
	DEBUG1(1,"Debugging Mode\n");
	}
if (!strncmp(argv[i],"-debug=",7)) 
	{
	iRRAM_debug=atoi(&(argv[i][7]));
	DEBUG2(1,"Debugging Level %d\n",iRRAM_debug);
	}
if (!strncmp(argv[i],"-prec_init=",11)) 
	{
	iRRAM_starting_prec=atoi(&(argv[i][11]));
	ACTUAL_STACK.actual_prec=iRRAM_starting_prec;
	DEBUG2(1,"Initialising precision to 2^(%ld)\n",iRRAM_starting_prec);
	}
if (!strncmp(argv[i],"-prec_inc=",10)) 
	{
	int hi;
	hi=atoi(&(argv[i][10]));
	if (hi>0) iRRAM_prec_inc1=-hi;
	DEBUG2(1,"Initialising precision increment to %ld bits\n",-iRRAM_prec_inc1);
	}
if (!strncmp(argv[i],"-prec_factor=",13)) 
	{
	double hd;
	hd=atof(&(argv[i][13]));
	if (hd>1.0) ACTUAL_STACK.prec_factor=hd;
	DEBUG2(1,"Initialising precision factor to %f\n",ACTUAL_STACK.prec_factor);
	}
}
eingabe=new char[eingabeplatz];
testwert=new long[100000];
konvert= new MP_type[100000];
ikonvert=new MP_int_type[100000];
rkonvert=new MP_rat_type[100000];
MP_initialize;
}

==> iRRAM_2004_01.tar.gz: iRRAM_2004_01/src/REALmain.cc <==
/*

REALmain.cc -- implementation of main initialization routine
               for the iRRAM library
 
Copyright (C) 2003 Norbert Mueller
 
This file is part of the iRRAM Library.
 
The iRRAM Library is free software; you can redistribute it and/or modify
it under the terms of the GNU Library General Public License as published by
the Free Software Foundation; either version 2 of the License, or (at your
option) any later version.
 
The iRRAM Library is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
License for more details.
 
You should have received a copy of the GNU Library General Public License
along with the iRRAM Library; see the file COPYING.LIB.  If not, write to
the Free Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
MA 02111-1307, USA. 
*/
#include <math.h>
#include <stdlib.h>
#include <stdarg.h>
#include <string.h>



#include "iRRAM_core.h"

/* for debugging (time measuring):*/
#include <sys/time.h>
#include <sys/resource.h>
#include <unistd.h>
void resources(double& time, unsigned long& memory){
 struct rusage r;
 getrusage (RUSAGE_SELF,&r);
 time = r.ru_utime.tv_sec+0.000001*r.ru_utime.tv_usec;
// the following is not yet evaluated by linux.... 
 memory = r.ru_ixrss+r.ru_idrss+r.ru_isrss;
} 
/* end of debugging aids */

long printfausgaben=0;
long printfaufrufe=0;
char * eingabe;
char * position=eingabe;
long  eingabeplatz=150000;

unsigned long cachesize_test=10;
unsigned long testanzahl=0;
unsigned long testaufrufe=0;
long * testwert;

unsigned long cachesize_rkonvert=10;
unsigned long rkonvertanzahl=0;
unsigned long rkonvertaufrufe=0;
MP_type * rkonvert;

int iRRAM_debug=0;
int iRRAM_infinite=0;
long iRRAM_starting_prec=-50;
long iRRAM_stiff_prec_inc=-50;
long iRRAM_prec_inc0=0;
long iRRAM_prec_inc1=-50;
long iRRAM_prec_inc2=-50;

extern "C" void iRRAM_initialize(int argc,char **argv)
{

ACTUAL_STACK.inlimit=0;
ACTUAL_STACK.actual_prec=iRRAM_starting_prec;
ACTUAL_STACK.prec_inc=0;
ACTUAL_STACK.prec_factor=1.25;

int i;

for (i=0;i<argc;i+=1)
{
if (!strcmp(argv[i],"-d")) 
	{
	iRRAM_debug=1;
	DEBUG1(1,"Debugging Mode\n");
	}
if (!strncmp(argv[i],"-debug=",7)) 
	{
	iRRAM_debug=atoi(&(argv[i][7]));
	DEBUG2(1,"Debugging Level %d\n",iRRAM_debug);
	}
if (!strncmp(argv[i],"-prec_init=",11)) 
	{
	iRRAM_starting_prec=atoi(&(argv[i][11]));
	ACTUAL_STACK.actual_prec=iRRAM_starting_prec;
	DEBUG2(1,"Initialising precision to 2^(%ld)\n",iRRAM_starting_prec);
	}
if (!strncmp(argv[i],"-prec_inc=",10)) 
	{
	int hi;
	hi=atoi(&(argv[i][10]));
	if (hi>0) iRRAM_prec_inc1=-hi;
	DEBUG2(1,"Initialising precision increment to %ld bits\n",-iRRAM_prec_inc1);
	}
if (!strncmp(argv[i],"-prec_factor=",13)) 
	{
	double hd;
	hd=atof(&(argv[i][13]));
	if (hd>1.0) ACTUAL_STACK.prec_factor=hd;
	DEBUG2(1,"Initialising precision factor to %f\n",ACTUAL_STACK.prec_factor);
	}
}
eingabe =new char[eingabeplatz];
testwert=new long[cachesize_test];
rkonvert=new MP_type[cachesize_rkonvert];
ikonvert=new MP_int_type[cachesize_ikonvert];
MP_initialize;
}
